<!DOCTYPE html>
<html>
  <head>
    <meta name="viewport" content="initial-scale=1.0, user-scalable=no">
    <meta charset="utf-8">
    <title>County Overlay</title>
    <link rel="stylesheet" href="CQX_StyleSheet-new.css" type="text/css" />

    <style>
      html, body, #map-canvas {
        height: 100%;
        margin: 0px;
        padding: 0px
      }
      html, body, #countySelection{width: 100%; height: 100%}
    </style>


    <script src="https://maps.googleapis.com/maps/api/js?v=3.exp"></script>

    <script language="javascript" type="text/javascript">

    var map;
    var infoWindow;
    var theCountyMarkers = new Array();
    var theCountyValues = new Array();
    var cqxUrl = "http://www.no5w.com";


    var stateFullName = "Kansas";
    var qsoPartyUrl = "http://www.ksqsoparty.org";
    var overlayUrl = "http://www.no5w.com/OverlayKansasRev3.kml";

    /*-----------------------------------------------------------------------------------------------------
     PromoControl: constructor for the QSO Party promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function PromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access QSO Party home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '24px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String(stateFullName) + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(qsoPartyUrl));
      });
    }//PromoControl constructor

    /*-----------------------------------------------------------------------------------------------------
     CQXPromoControl: constructor for the CQ/X promo control to add to the map
     -----------------------------------------------------------------------------------------------------*/
    function CQXPromoControl(controlDiv, map) {

      // Set CSS styles for the DIV containing the control
      // Setting padding to 5 px will offset the control
      // from the edge of the map.
      controlDiv.style.padding = '5px';

      // Set CSS for the control border.
      var controlUI = document.createElement('div');
      controlUI.style.backgroundColor = 'white';
      controlUI.style.borderStyle = 'solid';
      controlUI.style.borderWidth = '1px';
      controlUI.style.cursor = 'pointer';
      controlUI.style.textAlign = 'center';
      controlUI.title = 'Click to access CQ/X home page';
      controlDiv.appendChild(controlUI);

      // Set CSS for the control interior.
      var controlText = document.createElement('div');
      controlText.style.fontFamily = 'Arial,sans-serif';
      controlText.style.fontSize = '12px';
      controlText.style.paddingLeft = '3px';
      controlText.style.paddingRight = '3px';
      controlText.innerHTML = '<strong>' + String("CQ/X de NO5W") + '</strong>';
      controlUI.appendChild(controlText);

      google.maps.event.addDomListener(controlUI, 'click', function() {
        document.location.assign(String(cqxUrl));
      });
    }//CQXPromoControl constructor

/*-----------------------------------------------------------------------------------------------------
 addMarker: function for adding a county marker
-----------------------------------------------------------------------------------------------------*/
function addMarker(lat, lon, desc, aval) {
  var markerLatLng = new google.maps.LatLng(lat, lon);

  var markerOptions = {
    flat: true,
    map: map,
    optimized: false,
    position: markerLatLng,
    visible: true,
    title: desc
    };
  var marker = new google.maps.Marker(markerOptions);
  theCountyMarkers.push(marker);
  theCountyValues.push(aval);

  }//addMarker

/*-----------------------------------------------------------------------------------------------------
 removeMarkers: function for removing all of the current markers
 -----------------------------------------------------------------------------------------------------*/
function removeMarkers() {
  for(var i=0;i<theCountyMarkers.length;i++) theCountyMarkers[i].setMap(null);
  }//removeMarkers     

/*-----------------------------------------------------------------------------------------------------
 populateCountySelection: function for building the county selection
 -----------------------------------------------------------------------------------------------------*/
function populateCountySelection() {
  var countySelection = document.getElementById("countySelection");
          
  countySelection.options.length = 0;
  theCountyMarkers.length = 0;
  theCountyValues.length = 0;

  countySelection.options[0] = new Option("Allen", "all");
  countySelection.options[1] = new Option("Anderson", "and");
  countySelection.options[2] = new Option("Atchison", "atc");
  countySelection.options[3] = new Option("Barber", "bar");
  countySelection.options[4] = new Option("Barton", "brt");
  countySelection.options[5] = new Option("Bourbon", "bou");
  countySelection.options[6] = new Option("Brown", "bro");
  countySelection.options[7] = new Option("Butler", "but");
  countySelection.options[8] = new Option("Chase", "chs");
  countySelection.options[9] = new Option("Chautauqua", "cht");
  countySelection.options[10] = new Option("Cherokee", "che");
  countySelection.options[11] = new Option("Cheyenne", "chy");
  countySelection.options[12] = new Option("Clark", "clk");
  countySelection.options[13] = new Option("Clay", "cly");
  countySelection.options[14] = new Option("Cloud", "clo");
  countySelection.options[15] = new Option("Coffey", "cof");
  countySelection.options[16] = new Option("Comanche", "com");
  countySelection.options[17] = new Option("Cowley", "cow");
  countySelection.options[18] = new Option("Crawford", "cra");
  countySelection.options[19] = new Option("Decatur", "dec");
  countySelection.options[20] = new Option("Dickinson", "dic");
  countySelection.options[21] = new Option("Doniphan", "don");
  countySelection.options[22] = new Option("Douglas", "dou");
  countySelection.options[23] = new Option("Edwards", "edw");
  countySelection.options[24] = new Option("Elk", "elk");
  countySelection.options[25] = new Option("Ellis", "ell");
  countySelection.options[26] = new Option("Ellsworth", "els");
  countySelection.options[27] = new Option("Finney", "fin");
  countySelection.options[28] = new Option("Ford", "for");
  countySelection.options[29] = new Option("Franklin", "fra");
  countySelection.options[30] = new Option("Geary", "gea");
  countySelection.options[31] = new Option("Gove", "gov");
  countySelection.options[32] = new Option("Graham", "grm");
  countySelection.options[33] = new Option("Grant", "grt");
  countySelection.options[34] = new Option("Gray", "gry");
  countySelection.options[35] = new Option("Greeley", "gly");
  countySelection.options[36] = new Option("Greenwood", "gre");
  countySelection.options[37] = new Option("Hamilton", "ham");
  countySelection.options[38] = new Option("Harper", "hpr");
  countySelection.options[39] = new Option("Harvey", "hvy");
  countySelection.options[40] = new Option("Haskell", "has");
  countySelection.options[41] = new Option("Hodgeman", "hog");
  countySelection.options[42] = new Option("Jackson", "jac");
  countySelection.options[43] = new Option("Jefferson", "jef");
  countySelection.options[44] = new Option("Jewell", "jew");
  countySelection.options[45] = new Option("Johnson", "joh");
  countySelection.options[46] = new Option("Kearny", "kea");
  countySelection.options[47] = new Option("Kingman", "kin");
  countySelection.options[48] = new Option("Kiowa", "kio");
  countySelection.options[49] = new Option("Labette", "lab");
  countySelection.options[50] = new Option("Lane", "lan");
  countySelection.options[51] = new Option("Leavenworth", "lea");
  countySelection.options[52] = new Option("Lincoln", "lcn");
  countySelection.options[53] = new Option("Linn", "lin");
  countySelection.options[54] = new Option("Logan", "log");
  countySelection.options[55] = new Option("Lyon", "lyo");
  countySelection.options[56] = new Option("Marion", "mrn");
  countySelection.options[57] = new Option("Marshall", "msh");
  countySelection.options[58] = new Option("McPherson", "mcp");
  countySelection.options[59] = new Option("Meade", "mea");
  countySelection.options[60] = new Option("Miami", "mia");
  countySelection.options[61] = new Option("Mitchell", "mit");
  countySelection.options[62] = new Option("Montgomery", "mgy");
  countySelection.options[63] = new Option("Morris", "mor");
  countySelection.options[64] = new Option("Morton", "mtn");
  countySelection.options[65] = new Option("Nemaha", "nem");
  countySelection.options[66] = new Option("Neosho", "neo");
  countySelection.options[67] = new Option("Ness", "nes");
  countySelection.options[68] = new Option("Norton", "nor");
  countySelection.options[69] = new Option("Osage", "osa");
  countySelection.options[70] = new Option("Osborne", "osb");
  countySelection.options[71] = new Option("Ottawa", "ott");
  countySelection.options[72] = new Option("Pawnee", "paw");
  countySelection.options[73] = new Option("Phillips", "phi");
  countySelection.options[74] = new Option("Pottawatomie", "pot");
  countySelection.options[75] = new Option("Pratt", "pra");
  countySelection.options[76] = new Option("Rawlins", "raw");
  countySelection.options[77] = new Option("Reno", "ren");
  countySelection.options[78] = new Option("Republic", "rep");
  countySelection.options[79] = new Option("Rice", "ric");
  countySelection.options[80] = new Option("Riley", "ril");
  countySelection.options[81] = new Option("Rooks", "roo");
  countySelection.options[82] = new Option("Rush", "rus");
  countySelection.options[83] = new Option("Russell", "rsl");
  countySelection.options[84] = new Option("Saline", "sal");
  countySelection.options[85] = new Option("Scott", "sco");
  countySelection.options[86] = new Option("Sedgwick", "sed");
  countySelection.options[87] = new Option("Seward", "sew");
  countySelection.options[88] = new Option("Shawnee", "sha");
  countySelection.options[89] = new Option("Sheridan", "she");
  countySelection.options[90] = new Option("Sherman", "smn");
  countySelection.options[91] = new Option("Smith", "smi");
  countySelection.options[92] = new Option("Stafford", "sta");
  countySelection.options[93] = new Option("Stanton", "stn");
  countySelection.options[94] = new Option("Stevens", "ste");
  countySelection.options[95] = new Option("Sumner", "sum");
  countySelection.options[96] = new Option("Thomas", "tho");
  countySelection.options[97] = new Option("Trego", "tre");
  countySelection.options[98] = new Option("Wabaunsee", "wab");
  countySelection.options[99] = new Option("Wallace", "wal");
  countySelection.options[100] = new Option("Washington", "was");
  countySelection.options[101] = new Option("Wichita", "wic");
  countySelection.options[102] = new Option("Wilson", "wil");
  countySelection.options[103] = new Option("Woodson", "woo");
  countySelection.options[104] = new Option("Wyandotte", "wya");
  addMarker(37.88560000, -95.30170000, "Allen", "all");
  addMarker(38.21410000, -95.29210000, "Anderson", "and");
  addMarker(39.53590000, -95.26950000, "Atchison", "atc");
  addMarker(37.23460000, -98.67990000, "Barber", "bar");
  addMarker(38.47890000, -98.75650000, "Barton", "brt");
  addMarker(37.85540000, -94.85100000, "Bourbon", "bou");
  addMarker(39.82660000, -95.56430000, "Brown", "bro");
  addMarker(37.78150000, -96.83810000, "Butler", "but");
  addMarker(38.30400000, -96.59740000, "Chase", "chs");
  addMarker(37.15070000, -96.24490000, "Chautauqua", "cht");
  addMarker(37.16910000, -94.84650000, "Cherokee", "che");
  addMarker(39.78570000, -101.73100000, "Cheyenne", "chy");
  addMarker(37.23720000, -99.82420000, "Clark", "clk");
  addMarker(39.34950000, -97.16490000, "Clay", "cly");
  addMarker(39.48010000, -97.65020000, "Cloud", "clo");
  addMarker(38.23630000, -95.73350000, "Coffey", "cof");
  addMarker(37.19180000, -99.27280000, "Comanche", "com");
  addMarker(37.23770000, -96.83890000, "Cowley", "cow");
  addMarker(37.50660000, -94.85260000, "Crawford", "cra");
  addMarker(39.78460000, -100.45900000, "Decatur", "dec");
  addMarker(38.87110000, -97.13570000, "Dickinson", "dic");
  addMarker(39.81180000, -95.09970000, "Doniphan", "don");
  addMarker(38.90400000, -95.27850000, "Douglas", "dou");
  addMarker(37.91050000, -99.29180000, "Edwards", "edw");
  addMarker(37.45320000, -96.24370000, "Elk", "elk");
  addMarker(38.91490000, -99.31800000, "Ellis", "ell");
  addMarker(38.69660000, -98.20520000, "Ellsworth", "els");
  addMarker(38.00080000, -100.66500000, "Finney", "fin");
  addMarker(37.69050000, -99.89180000, "Ford", "for");
  addMarker(38.56430000, -95.28270000, "Franklin", "fra");
  addMarker(39.04500000, -96.73240000, "Geary", "gea");
  addMarker(38.91530000, -100.48300000, "Gove", "gov");
  addMarker(39.34960000, -99.88320000, "Graham", "grm");
  addMarker(37.56210000, -101.30800000, "Grant", "grt");
  addMarker(37.73870000, -100.44000000, "Gray", "gry");
  addMarker(38.48100000, -101.80600000, "Greeley", "gly");
  addMarker(37.88830000, -96.24210000, "Greenwood", "gre");
  addMarker(37.99970000, -101.78600000, "Hamilton", "ham");
  addMarker(37.19210000, -98.07590000, "Harper", "hpr");
  addMarker(38.04350000, -97.42740000, "Harvey", "hvy");
  addMarker(37.56220000, -100.87100000, "Haskell", "has");
  addMarker(38.08750000, -99.89830000, "Hodgeman", "hog");
  addMarker(39.43470000, -95.80020000, "Jackson", "jac");
  addMarker(39.22620000, -95.38890000, "Jefferson", "jef");
  addMarker(39.78480000, -98.21850000, "Jewell", "jew");
  addMarker(38.89990000, -94.83200000, "Johnson", "joh");
  addMarker(38.00030000, -101.31600000, "Kearny", "kea");
  addMarker(37.55900000, -98.13600000, "Kingman", "kin");
  addMarker(37.55800000, -99.28560000, "Kiowa", "kio");
  addMarker(37.19180000, -95.29810000, "Labette", "lab");
  addMarker(38.48130000, -100.46600000, "Lane", "lan");
  addMarker(39.18680000, -94.98180000, "Leavenworth", "lea");
  addMarker(39.04520000, -98.20930000, "Lincoln", "lcn");
  addMarker(38.21340000, -94.84520000, "Linn", "lin");
  addMarker(38.91720000, -101.14800000, "Logan", "log");
  addMarker(38.45520000, -96.15140000, "Lyon", "lyo");
  addMarker(38.34750000, -97.09570000, "Marion", "mrn");
  addMarker(39.78370000, -96.52280000, "Marshall", "msh");
  addMarker(38.39160000, -97.64840000, "McPherson", "mcp");
  addMarker(37.23760000, -100.37100000, "Meade", "mea");
  addMarker(38.56370000, -94.83770000, "Miami", "mia");
  addMarker(39.39320000, -98.20940000, "Mitchell", "mit");
  addMarker(37.19290000, -95.74140000, "Montgomery", "mgy");
  addMarker(38.69600000, -96.64160000, "Morris", "mor");
  addMarker(37.19120000, -101.79900000, "Morton", "mtn");
  addMarker(39.78330000, -96.01390000, "Nemaha", "nem");
  addMarker(37.55910000, -95.30690000, "Neosho", "neo");
  addMarker(38.47980000, -99.91650000, "Ness", "nes");
  addMarker(39.78430000, -99.90300000, "Norton", "nor");
  addMarker(38.65200000, -95.72550000, "Osage", "osa");
  addMarker(39.35040000, -98.76800000, "Osborne", "osb");
  addMarker(39.13230000, -97.65070000, "Ottawa", "ott");
  addMarker(38.17510000, -99.24860000, "Pawnee", "paw");
  addMarker(39.78470000, -99.34700000, "Phillips", "phi");
  addMarker(39.34640000, -96.38150000, "Pottawatomie", "pot");
  addMarker(37.64790000, -98.74000000, "Pratt", "pra");
  addMarker(39.78520000, -101.07600000, "Rawlins", "raw");
  addMarker(37.95320000, -98.08590000, "Reno", "ren");
  addMarker(39.82780000, -97.65090000, "Republic", "rep");
  addMarker(38.34070000, -98.20150000, "Rice", "ric");
  addMarker(39.30490000, -96.67530000, "Riley", "ril");
  addMarker(39.35020000, -99.32490000, "Rooks", "roo");
  addMarker(38.52290000, -99.30960000, "Rush", "rus");
  addMarker(38.91510000, -98.76310000, "Russell", "rsl");
  addMarker(38.78360000, -97.65040000, "Saline", "sal");
  addMarker(38.48240000, -100.90600000, "Scott", "sco");
  addMarker(37.69360000, -97.48040000, "Sedgwick", "sed");
  addMarker(37.19290000, -100.85100000, "Seward", "sew");
  addMarker(39.04290000, -95.76970000, "Shawnee", "sha");
  addMarker(39.35000000, -100.44200000, "Sheridan", "she");
  addMarker(39.35080000, -101.71900000, "Sherman", "smn");
  addMarker(39.78500000, -98.78560000, "Smith", "smi");
  addMarker(38.04280000, -98.74720000, "Stafford", "sta");
  addMarker(37.56350000, -101.78400000, "Stanton", "stn");
  addMarker(37.19200000, -101.31200000, "Stevens", "ste");
  addMarker(37.23790000, -97.47760000, "Sumner", "sum");
  addMarker(39.35070000, -101.05600000, "Thomas", "tho");
  addMarker(38.91440000, -99.87290000, "Trego", "tre");
  addMarker(38.97550000, -96.22380000, "Wabaunsee", "wab");
  addMarker(38.91620000, -101.76300000, "Wallace", "wal");
  addMarker(39.78420000, -97.08680000, "Washington", "was");
  addMarker(38.48230000, -101.34700000, "Wichita", "wic");
  addMarker(37.55920000, -95.74380000, "Wilson", "wil");
  addMarker(37.88660000, -95.74030000, "Woodson", "woo");
  addMarker(39.09660000, -94.74950000, "Wyandotte", "wya");

  countySelection.selectedIndex = 0;
  }

//----------------------------------------------------------------------------------------------------

function initialize() {

  populateCountySelection();

  var mapOptions = {
    zoom: 11
    };

  map = new google.maps.Map(document.getElementById('map-canvas'), mapOptions);

  var stateLayer = new google.maps.KmlLayer({url: overlayUrl, suppressInfoWindows: true});
  stateLayer.setMap(map);

  // Add a listener for the click event.
  google.maps.event.addListener(stateLayer, 'click', showLatLon);

  infoWindow = new google.maps.InfoWindow();

  var promoControlDiv = document.createElement('div');
  var promoControl = new PromoControl(promoControlDiv, map);

  promoControlDiv.index = 1;
  map.controls[google.maps.ControlPosition.TOP_CENTER].push(promoControlDiv);

  var promoCQXControlDiv = document.createElement('div');
  var promoCQXControl = new CQXPromoControl(promoCQXControlDiv, map);

  promoCQXControlDiv.index = 2;
  map.controls[google.maps.ControlPosition.TOP_RIGHT].push(promoCQXControlDiv);

  }

/*-----------------------------------------------------------------------------------------------------
 changeCounty: function processing a county change from the countySelection 
 -----------------------------------------------------------------------------------------------------*/
function changeCounty() {
  removeMarkers();
  var acounty = encodeURIComponent(document.getElementById("countySelection").value);
  var iMark = -1;
  for(i=0;i<theCountyValues.length;i++) {
    if(theCountyValues[i] != acounty) continue;
    iMark = i;
    break;
    }
  if(iMark < 0) return;
  map.setCenter(theCountyMarkers[iMark].getPosition());
  theCountyMarkers[iMark].setMap(map);
  }//function changeCounty

function catchEvent(eventObj, event, eventHandler) {
  if(eventObj.addEventListener) {
    eventObj.addEventListener(event, eventHandler, false);
    }
  else if(eventObj.attachEvent) {
    event = "on" + event;
    eventObj.attachEvent(event, eventHandler);
    }
  }//catchEvent

/*-----------------------------------------------------------------------------------------------------
 set up event handlers when the window loads 
 -----------------------------------------------------------------------------------------------------*/
catchEvent(window, "load", function() {
  document.getElementById("countySelection").onchange=changeCounty;
  });

function showLatLon(event) {

  var nameStr = event.featureData.name; //FullName=Abbrev Num
  var arrayOne = nameStr.split("=");
  var arrayTwo = arrayOne[1].split(" ");

  var contentString = '<b>Clicked on Location</b>' + '<br>' +
                    '<b>LatLon: </b>' + event.latLng.lat() + ',' + event.latLng.lng() + '<br>' +
                    '<b>In County: </b>' + arrayOne[0] + '(' + arrayTwo[0] + ')';

  // Replace the info window's content and position.
  infoWindow.setContent(contentString);
  infoWindow.setPosition(event.latLng);

  infoWindow.open(map);
  }

google.maps.event.addDomListener(window, 'load', initialize);


    </script>
  </head>

  <body>

    <table style="width: 1000px;">
      <tbody>
        <tr style="vertical-align: top;">

          <td>
          <form>
            <div class="elem" style = "width: 120px; height: 700px; margin: 0; padding: 0; overflow:auto;">
              <select id="countySelection" name="county" size='43'>
                <option> </option>
              </select>
            </div>
          </form>
          </td>

          <td>
            <div id="map-canvas" style="width: 880px; height: 700px;"></div>
          </td>
        </tr>
      </tbody>
    </table>

  </body>


</html>

